==> kubernetes-model-admissionregistration-4.10.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/admissionregistration/v1/ValidatingWebhookConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ValidatingWebhookConfigurationFluent<A extends ValidatingWebhookConfigurationFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public ValidatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata();
    public ValidatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public ValidatingWebhookConfigurationFluent.MetadataNested<A> editMetadata();
    public ValidatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata();
    public ValidatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToWebhooks(int index,ValidatingWebhook item);
    public A setToWebhooks(int index,ValidatingWebhook item);
    public A addToWebhooks(ValidatingWebhook... items);
    public A addAllToWebhooks(Collection<ValidatingWebhook> items);
    public A removeFromWebhooks(ValidatingWebhook... items);
    public A removeAllFromWebhooks(Collection<ValidatingWebhook> items);
    public A removeMatchingFromWebhooks(io.fabric8.kubernetes.api.builder.Predicate<ValidatingWebhookBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildWebhooks instead.
 * @return The buildable object.
 */
@Deprecated public List<ValidatingWebhook> getWebhooks();
    public List<ValidatingWebhook> buildWebhooks();
    public ValidatingWebhook buildWebhook(int index);
    public ValidatingWebhook buildFirstWebhook();
    public ValidatingWebhook buildLastWebhook();
    public ValidatingWebhook buildMatchingWebhook(io.fabric8.kubernetes.api.builder.Predicate<ValidatingWebhookBuilder> predicate);
    public Boolean hasMatchingWebhook(io.fabric8.kubernetes.api.builder.Predicate<ValidatingWebhookBuilder> predicate);
    public A withWebhooks(List<ValidatingWebhook> webhooks);
    public A withWebhooks(ValidatingWebhook... webhooks);
    public Boolean hasWebhooks();
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook();
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(ValidatingWebhook item);
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(int index,ValidatingWebhook item);
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(int index);
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook();
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook();
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(io.fabric8.kubernetes.api.builder.Predicate<ValidatingWebhookBuilder> predicate);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<ValidatingWebhookConfigurationFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface WebhooksNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ValidatingWebhookFluent<ValidatingWebhookConfigurationFluent.WebhooksNested<N>>{

        
    public N and();    public N endWebhook();
}


}

==> kubernetes-model-admissionregistration-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/admissionregistration/v1/ValidatingWebhookConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ValidatingWebhookConfigurationFluent<A extends ValidatingWebhookConfigurationFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public ValidatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata();
    public ValidatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public ValidatingWebhookConfigurationFluent.MetadataNested<A> editMetadata();
    public ValidatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata();
    public ValidatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public A addToWebhooks(int index,ValidatingWebhook item);
    public A setToWebhooks(int index,ValidatingWebhook item);
    public A addToWebhooks(ValidatingWebhook... items);
    public A addAllToWebhooks(Collection<ValidatingWebhook> items);
    public A removeFromWebhooks(ValidatingWebhook... items);
    public A removeAllFromWebhooks(Collection<ValidatingWebhook> items);
    public A removeMatchingFromWebhooks(Predicate<ValidatingWebhookBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildWebhooks instead.
 * @return The buildable object.
 */
@Deprecated public List<ValidatingWebhook> getWebhooks();
    public List<ValidatingWebhook> buildWebhooks();
    public ValidatingWebhook buildWebhook(int index);
    public ValidatingWebhook buildFirstWebhook();
    public ValidatingWebhook buildLastWebhook();
    public ValidatingWebhook buildMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate);
    public Boolean hasMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate);
    public A withWebhooks(List<ValidatingWebhook> webhooks);
    public A withWebhooks(ValidatingWebhook... webhooks);
    public Boolean hasWebhooks();
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook();
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(ValidatingWebhook item);
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(int index,ValidatingWebhook item);
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(int index);
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook();
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook();
    public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<ValidatingWebhookConfigurationFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface WebhooksNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ValidatingWebhookFluent<ValidatingWebhookConfigurationFluent.WebhooksNested<N>> {

            public N and();
            public N endWebhook();    }


}
